@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.348.2.36 2007/11/17 20:34:38 dolorous Exp $ */
+/* $Id: files.c 4307 2008-08-17 16:31:11Z astyanax $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -1564,7 +1564,7 @@ bool write_file(const char *name, FILE *f_open, bool tmp, append_type
 	}
 
 	if (f_open == NULL) {
-	    fd_source = open(realname, O_RDONLY | O_CREAT);
+	    fd_source = open(realname, O_RDONLY | O_CREAT, S_IRUSR | S_IWUSR);
 
 	    if (fd_source != -1) {
 		f_source = fdopen(fd_source, "rb");
@@ -1683,7 +1683,7 @@ bool write_file(const char *name, FILE *f_open, bool tmp, append_type
 	int fd_source;
 	FILE *f_source = NULL;
 
-	fd_source = open(tempname, O_RDONLY | O_CREAT);
+	fd_source = open(tempname, O_RDONLY | O_CREAT, S_IRUSR | S_IWUSR);
 
 	if (fd_source != -1) {
 	    f_source = fdopen(fd_source, "rb");
@@ -1704,8 +1704,11 @@ bool write_file(const char *name, FILE *f_open, bool tmp, append_type
 		strerror(errno));
 	    goto cleanup_and_exit;
 	}
-    } else
-	fclose(f);
+    } else if (fclose(f) != 0) {
+	    statusbar(_("Error writing %s: %s"), realname,
+		strerror(errno));
+	    goto cleanup_and_exit;
+    }
 
     if (!tmp && append == OVERWRITE) {
 	if (!nonamechange) {
@@ -2384,7 +2387,7 @@ char *input_tab(char *buf, bool allow_files, size_t *place, bool
 	} else if (!*lastwastab || num_matches < 2)
 	    *lastwastab = TRUE;
 	else {
-	    int longest_name = 0, columns, editline = 0;
+	    int longest_name = 0, ncols, editline = 0;
 
 	    /* Now we show a list of the available choices. */
 	    assert(num_matches > 1);
@@ -2409,7 +2412,7 @@ char *input_tab(char *buf, bool allow_files, size_t *place, bool
 	    /* Each column will be (longest_name + 2) columns wide, i.e.
 	     * two spaces between columns, except that there will be
 	     * only one space after the last column. */
-	    columns = (COLS + 1) / (longest_name + 2);
+	    ncols = (COLS + 1) / (longest_name + 2);
 
 	    /* Blank the edit window, and print the matches out
 	     * there. */
@@ -2423,11 +2426,11 @@ char *input_tab(char *buf, bool allow_files, size_t *place, bool
 		char *disp;
 
 		wmove(edit, editline, (longest_name + 2) *
-			(match % columns));
+			(match % ncols));
 
-		if (match % columns == 0 &&
+		if (match % ncols == 0 &&
 			editline == editwinrows - 1 &&
-			num_matches - match > columns) {
+			num_matches - match > ncols) {
 		    waddstr(edit, _("(more)"));
 		    break;
 		}
@@ -2437,7 +2440,7 @@ char *input_tab(char *buf, bool allow_files, size_t *place, bool
 		waddstr(edit, disp);
 		free(disp);
 
-		if ((match + 1) % columns == 0)
+		if ((match + 1) % ncols == 0)
 		    editline++;
 	    }
 
