@@ -1,4 +1,4 @@
-/* $Id: nano.c,v 1.582.2.23 2007/12/18 22:00:17 dolorous Exp $ */
+/* $Id: nano.c 4258 2008-05-31 22:41:09Z astyanax $ */
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -610,7 +610,7 @@ void die(const char *msg, ...)
     va_end(ap);
 
     /* Save the current file buffer if it's been modified. */
-    if (openfile->modified) {
+    if (openfile && openfile->modified) {
 	/* If we've partitioned the filestruct, unpartition it now. */
 	if (filepart != NULL)
 	    unpartition_filestruct(&filepart);
